-- Copyright (C) 2010-2011 Papavasileiou Dimitris                       
--                                                                      
-- This program is free software: you can redistribute it and/or modify 
-- it under the terms of the GNU General Public License as published by 
-- the Free Software Foundation, either version 3 of the License, or    
-- (at your option) any later version.                                  
--                                                                      
-- This program is distributed in the hope that it will be useful,      
-- but WITHOUT ANY WARRANTY; without even the implied warranty of       
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
-- GNU General Public License for more details.                         
--                                                                      
-- You should have received a copy of the GNU General Public License    
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.

blueprint.anchor = {0.5, 0.75}

blueprint.steeringsensitivity = {0.1, 0.08, 2.2}
blueprint.steeringlag = 0.05

blueprint.throttlesensitivity = 0.0017
blueprint.throttlelag = 0.1
blueprint.limiterthreshold = 15000
blueprint.limiterhysteresis = 300

blueprint.rearbrakesensitivity = 1.2
blueprint.rearbrakelag = 0.05

blueprint.frontbrakelag = 0.05
blueprint.frontbrakesensitivity = 3.5

blueprint.riderroll = {380, 34}
blueprint.rideryaw = {820, 90}
blueprint.ridercoupling = {130, 5}

blueprint.loadregion = {100, 0}
blueprint.sideslipregion = {0.03, 0.1}